FLASH_CTRL

Struct FLASH_CTRL 

pub struct FLASH_CTRL { /* private fields */ }
FLASH_CTRL unit

Implementations

Source

impl FLASH_CTRL

pub const PTR: *const RegisterBlock = {0x4006f000 as *const flash_ctrl::RegisterBlock}

Pointer to the register block

pub const fn ptr() -> *const RegisterBlock

Return the pointer to the register block

pub unsafe fn steal() -> Self

Steal an instance of this peripheral

Safety

Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.

Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.

Methods from Deref<Target = RegisterBlock>

pub fn flash_cfg(&self) -> &FLASH_CFG

0x00 - Flash configuration register

pub fn flash_addr(&self) -> &FLASH_ADDR

0x04 - Flash Address Configuration Register

pub fn flash_wdata(&self) -> &FLASH_WDATA

0x08 - Flash write data register

pub fn flash_rdata(&self) -> &FLASH_RDATA

0x0c - Flash read data register

pub fn flash_start(&self) -> &FLASH_START

0x10 - Flash Operation Start Register

pub fn flash_st(&self) -> &FLASH_ST

0x14 - Flash status register

pub fn flash_lock(&self) -> &FLASH_LOCK

0x18 - Flash Operation Lock Control Register

pub fn flash_unlock(&self) -> &FLASH_UNLOCK

0x1c - Flash Operation Unlock Control Register

pub fn flash_mask(&self) -> &FLASH_MASK

0x20 - Flash mask control register

pub fn flash_erasetime(&self) -> &FLASH_ERASETIME

0x24 - Flash Erase Time Parameter Configuration Register

pub fn flash_progtime(&self) -> &FLASH_PROGTIME

0x28 - Flash Program Time Parameter Configuration Register