PMU

Struct PMU 

pub struct PMU { /* private fields */ }
Power management unit

Implementations

Source

impl PMU

pub const PTR: *const RegisterBlock = {0x40000800 as *const pmu::RegisterBlock}

Pointer to the register block

pub const fn ptr() -> *const RegisterBlock

Return the pointer to the register block

pub unsafe fn steal() -> Self

Steal an instance of this peripheral

Safety

Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.

Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.

Methods from Deref<Target = RegisterBlock>

pub fn lpow_md(&self) -> &LPOW_MD

0x00 - Low Power Mode Select Register

pub fn lpmd_wken(&self) -> &LPMD_WKEN

0x04 - Low Power Wakeup Source Enable Register

pub fn lpmd_wkst(&self) -> &LPMD_WKST

0x08 - Low Power Wakeup Source Status Register

pub fn chip_rst_st(&self) -> &CHIP_RST_ST

0x0c - Chip Reset Status Register

pub fn src_cfg(&self) -> &SRC_CFG

0x10 - Clock Source Configuration Register

pub fn trim_pow0(&self) -> &TRIM_POW0

0x20 - POW0 Related Analog Modules TRIM register

pub fn trim_pow1(&self) -> &TRIM_POW1

0x24 - POW1 Related Analog Modules TRIM register

pub fn trim_pow2(&self) -> &TRIM_POW2

0x28 - POW2 Related Analog Modules TRIM register

pub fn trim_pow3(&self) -> &TRIM_POW3

0x2c - POW3 Related Analog Modules TRIM register

pub fn trim_rchf(&self) -> &TRIM_RCHF

0x30 - RCHF Clock Module TRIM Register

pub fn trim_rclf(&self) -> &TRIM_RCLF

0x34 - RCLF Clock Module TRIM Register

pub fn trim_opa(&self) -> &TRIM_OPA

0x38 - OPA Module TRIM Register

pub fn trim_pll(&self) -> &TRIM_PLL

0x3c - PLL Module TRIM Register

pub fn trim_lock(&self) -> &TRIM_LOCK

0x80 - TRIM Locks the registers

pub fn data_bak0(&self) -> &DATA_BAK0

0x100 - Non-power-off domain data backup register0

pub fn data_bak1(&self) -> &DATA_BAK1

0x104 - Non-power-off domain data backup register1

pub fn data_bak2(&self) -> &DATA_BAK2

0x108 - Non-power-off domain data backup register2

pub fn data_bak3(&self) -> &DATA_BAK3

0x10c - Non-power-off domain data backup register3