pub type ABRDBIT_R = FieldReader;Expand description
Field ABRDBIT reader - Automatic baud rate detection bit length configuration 11: 8-bit duration from the start bit to the first rising edge. Input data is 0x80. 10: 4-bit duration from the start bit to the first rising edge. The input data is 0x08. 01: 2-bit duration from the start bit to the first rising edge. Input data is 0x02. 00: 1-bit duration from the start bit to the first rising edge. The input data is 0x01.
Aliased Type
pub struct ABRDBIT_R { /* private fields */ }