pub struct FLASH_CTRL { /* private fields */ }Expand description
FLASH_CTRL unit
Implementations
Sourceimpl FLASH_CTRL
impl FLASH_CTRL
Sourcepub const PTR: *const RegisterBlock = {0x4006f000 as *const flash_ctrl::RegisterBlock}
pub const PTR: *const RegisterBlock = {0x4006f000 as *const flash_ctrl::RegisterBlock}
Pointer to the register block
Sourcepub const fn ptr() -> *const RegisterBlock
pub const fn ptr() -> *const RegisterBlock
Return the pointer to the register block
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Steal an instance of this peripheral
Safety
Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.
Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.
Methods from Deref<Target = RegisterBlock>
Sourcepub fn flash_addr(&self) -> &FLASH_ADDR
pub fn flash_addr(&self) -> &FLASH_ADDR
0x04 - Flash Address Configuration Register
Sourcepub fn flash_wdata(&self) -> &FLASH_WDATA
pub fn flash_wdata(&self) -> &FLASH_WDATA
0x08 - Flash write data register
Sourcepub fn flash_rdata(&self) -> &FLASH_RDATA
pub fn flash_rdata(&self) -> &FLASH_RDATA
0x0c - Flash read data register
Sourcepub fn flash_start(&self) -> &FLASH_START
pub fn flash_start(&self) -> &FLASH_START
0x10 - Flash Operation Start Register
Sourcepub fn flash_lock(&self) -> &FLASH_LOCK
pub fn flash_lock(&self) -> &FLASH_LOCK
0x18 - Flash Operation Lock Control Register
Sourcepub fn flash_unlock(&self) -> &FLASH_UNLOCK
pub fn flash_unlock(&self) -> &FLASH_UNLOCK
0x1c - Flash Operation Unlock Control Register
Sourcepub fn flash_mask(&self) -> &FLASH_MASK
pub fn flash_mask(&self) -> &FLASH_MASK
0x20 - Flash mask control register
Sourcepub fn flash_erasetime(&self) -> &FLASH_ERASETIME
pub fn flash_erasetime(&self) -> &FLASH_ERASETIME
0x24 - Flash Erase Time Parameter Configuration Register
Sourcepub fn flash_progtime(&self) -> &FLASH_PROGTIME
pub fn flash_progtime(&self) -> &FLASH_PROGTIME
0x28 - Flash Program Time Parameter Configuration Register