pub struct PWM_BASE1 { /* private fields */ }Expand description
PWM_BASE1 unit
Implementations
Sourceimpl PWM_BASE1
impl PWM_BASE1
Sourcepub const PTR: *const RegisterBlock = {0x400b1800 as *const pwm_base1::RegisterBlock}
pub const PTR: *const RegisterBlock = {0x400b1800 as *const pwm_base1::RegisterBlock}
Pointer to the register block
Sourcepub const fn ptr() -> *const RegisterBlock
pub const fn ptr() -> *const RegisterBlock
Return the pointer to the register block
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Steal an instance of this peripheral
Safety
Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.
Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.
Methods from Deref<Target = RegisterBlock>
Sourcepub fn pwmbase1_en(&self) -> &PWMBASE1_EN
pub fn pwmbase1_en(&self) -> &PWMBASE1_EN
0x00 - PWMBASE enable register
Sourcepub fn pwmbase1_div(&self) -> &PWMBASE1_DIV
pub fn pwmbase1_div(&self) -> &PWMBASE1_DIV
0x04 - PWMBASE Clock Prescaler Register
Sourcepub fn pwmbase1_con(&self) -> &PWMBASE1_CON
pub fn pwmbase1_con(&self) -> &PWMBASE1_CON
0x08 - PWMBASE Output Configuration Register
Sourcepub fn pwmbase1_period(&self) -> &PWMBASE1_PERIOD
pub fn pwmbase1_period(&self) -> &PWMBASE1_PERIOD
0x0c - PWMBASE Period configuration register
Sourcepub fn pwmbase1_ie(&self) -> &PWMBASE1_IE
pub fn pwmbase1_ie(&self) -> &PWMBASE1_IE
0x10 - PWMBASE interrupt enable register
Sourcepub fn pwmbase1_if(&self) -> &PWMBASE1_IF
pub fn pwmbase1_if(&self) -> &PWMBASE1_IF
0x14 - PWMBASE Interrupt Status Register
Sourcepub fn pwmbase1_cnt(&self) -> &PWMBASE1_CNT
pub fn pwmbase1_cnt(&self) -> &PWMBASE1_CNT
0x18 - PWMBASE Current count value register
Sourcepub fn pwmbase1_ch0_comp(&self) -> &PWMBASE1_CH0_COMP
pub fn pwmbase1_ch0_comp(&self) -> &PWMBASE1_CH0_COMP
0x20 - PWMBASE Channel 0 Flip Point Configuration Register
Sourcepub fn pwmbase1_ch1_comp(&self) -> &PWMBASE1_CH1_COMP
pub fn pwmbase1_ch1_comp(&self) -> &PWMBASE1_CH1_COMP
0x30 - PWMBASE Channel 1 Flip Point Configuration Register
Sourcepub fn pwmbase1_ch2_comp(&self) -> &PWMBASE1_CH2_COMP
pub fn pwmbase1_ch2_comp(&self) -> &PWMBASE1_CH2_COMP
0x40 - PWMBASE Channel 2 Flip Point Configuration Register